..
   Copyright (C) 2011,2012 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


Developer guide
***************

This chapter provides basic information for developers about contributing, the
theoretical background and the core structure.  It is assumed that the reader
has read and is familiar with :ref:`sec-user-guide`.

.. toctree::
   :maxdepth: 2

   workflow
   vmp
   engine
   writingnodes

